//
// C++ Interface: CSplEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CSPLEDITDLG_H
#define CSPLEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_spldlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CSplEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CSplEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CSplEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
    virtual void slotEditorScript();
 
private slots:
 
protected:
    Ui::SplEditDlg ui;    
    FolderListItem *point;
    
private:
    QWidget *myParent;
};
#endif
